@@ -23,7 +23,6 @@
 #include <language/duchain/types/functiontype.h>
 #include <language/duchain/aliasdeclaration.h>
 #include <language/duchain/types/containertypes.h>
-#include <shell/partcontroller.h>
 
 #include <KTextEditor/View>
 #include <KTextEditor/Document>
@@ -36,7 +35,7 @@
 #include "duchain/helpers.h"
 
 #include <QDebug>
-#include "../codecompletiondebug.h"
+#include <codecompletiondebug.h>
 
 using namespace KDevelop;
 using namespace KTextEditor;
@@ -84,7 +83,7 @@ QVariant FunctionDeclarationCompletionItem::data(const QModelIndex& index, int r
             if ( index.column() == KDevelop::CodeCompletionModel::Arguments ) {
                 if (FunctionType::Ptr functionType = dec->type<FunctionType>()) {
                     QString ret;
-                    createArgumentList(dec, ret, 0, 0, false);
+                    createArgumentList(dec, ret, nullptr, 0, false);
                     return ret;
                 }
             }
@@ -110,7 +109,7 @@ QVariant FunctionDeclarationCompletionItem::data(const QModelIndex& index, int r
                     createArgumentList(dec, ret, &highlight, atArgument(), false);
                 }
                 else {
-                    createArgumentList(dec, ret, 0, false);
+                    createArgumentList(dec, ret, nullptr, false);
                 }
                 return QVariant(highlight);
             }
