@@ -43,11 +43,8 @@
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/idocumentcontroller.h>
-#include <interfaces/ipartcontroller.h>
 #include <util/path.h>
 
-#include <shell/partcontroller.h>
-
 #include <KTextEditor/View>
 #include <KConfigGroup>
 
@@ -95,7 +92,7 @@ void Helper::scheduleDependency(const IndexedString& dependency, int betterThanP
 IndexedDeclaration Helper::declarationUnderCursor(bool allowUse)
 {
     KDevelop::IDocument* doc = ICore::self()->documentController()->activeDocument();
-    const auto view = static_cast<KDevelop::PartController*>(ICore::self()->partController())->activeView();
+    const auto view = ICore::self()->documentController()->activeTextDocumentView();
     if ( doc && doc->textDocument() && view ) {
         DUChainReadLocker lock;
         const auto cursor = view->cursorPosition();
@@ -181,8 +178,8 @@ Declaration* Helper::declarationForName(const QString& name, const CursorInRevis
 {
     DUChainReadLocker lock(DUChain::lock());
     auto identifier = KDevelop::Identifier(name);
-    auto localDeclarations = context->findLocalDeclarations(identifier, location, 0,
-                                                            AbstractType::Ptr(0), DUContext::DontResolveAliases);
+    auto localDeclarations = context->findLocalDeclarations(identifier, location, nullptr,
+                                                            AbstractType::Ptr(), DUContext::DontResolveAliases);
     if ( !localDeclarations.isEmpty() ) {
         return localDeclarations.last();
     }
